@@ -14,19 +14,22 @@
 # limitations under the License.
 # ----------------------------------------------------------------------------
 
-SOCKET_RADIUS = 6
+SOCKET_RADIUS = 5
 SOCKET_HIT_RADIUS = 10
 
 SOCKET_INPUT = 0
 SOCKET_OUTPUT = 1
 
 SOCKET_DATATYPES = {
-    "RENDERIMAGE": "#C6C62D",
-    "VALUE": "#A0A0A0",
+    "RGBAIMAGE": "#C6C62D",  # Yellow
+    "VALUE": "#A0A0A0",  # Grey
 }
 
+WIRE_NORMAL_COLOR = "#808080"
+WIRE_ACTIVE_COLOR = "#ECECEC"
+
 NODE_CATEGORY_COLORS = {
-    "INPUT": "#975B5B",  # Burgendy
+    "INPUT": "#E64555",  # Burgendy
     "DRAW": "#AF4467",  # Pink
     "MASK": "#084D4D",  # Blue-green
     "CONVERT": "#564B7C",  # Purple
@@ -34,10 +37,12 @@ NODE_CATEGORY_COLORS = {
     "FILTER": "#558333",  # Green
     "BLEND": "#498DB8",  # Light blue
     "COLOR": "#C2AF3A",  # Yellow
-    "DISTORT": "#6B8B8B",  # Blue-Grey
+    "TRANSFORM": "#6B8B8B", # Blue-grey
     "OUTPUT": "#B33641",  # Red
     "DEFAULT": "#975B5B"  # Burgendy
 }
 
 NODE_DEFAULT_WIDTH = 136
 NODE_DEFAULT_HEIGHT = 150
+NODE_THUMB_PADDING = 16
+NODE_Y_PADDING = 10
